@@ -124,7 +124,8 @@ char *amap_get_data_token(char *data, char token) {
 int amap_webupdate_file(char *webfile, char *localfile, int checkversion, int ask) {
   int len = strlen("http://");
   int wlen = strlen(webfile);
-  int port = 80, s, result = 1, datalen = 0, version = -1, newversion;
+  int port = 80, s, result = 1, datalen = 0, version = -1;
+int xx = 0;
   unsigned long int ip;
   time_t epoch;
   struct in_addr in;
@@ -149,22 +150,37 @@ int amap_webupdate_file(char *webfile, char *localfile, int checkversion, int as
   if ((ptr = index(host, ':')) != NULL) {
     *ptr++ = 0;
     port = atoi(ptr);
-    if (port < 1 || port > 65535)
+    if (port < 0 || port > 65535)
       amap_error("invalid port: %s", ptr);
   }
   snprintf(request, AMAP_WEBBUFLEN + wlen, "GET %s HTTP/1.0\r\nHost: %s:%d\r\nUser-Agent: %s %s\r\n\r\n", url, host, port, AMAP_PROGRAM, AMAP_VERSION);
 
-#ifdef AF_INET6
-  if (inet_pton(AF_INET, host, &in) < 0) {
-#else
-  if (inet_aton(host, &in) <= 0) {
-#endif
-    if ((target = gethostbyname(host)) != NULL)
+//#ifdef AF_INET6
+//printf("uses pton\n");
+//  if ((xx = inet_pton(AF_INET, host, &in)) < 0) {
+//printf("failed %d: %d %s\n",xx,AF_INET,host);
+//#else
+//printf("uses aton\n");
+//  if ((xx=inet_aton(host, &in)) <= 0) {
+//printf("failed %d: %d %s\n",xx,AF_INET,host);
+//#endif
+    if ((target = gethostbyname(host)) != NULL) {
       memcpy((char*)&ip, (char*)target->h_addr, 4);
-    else
+    } else
       amap_error("could not resolve host: %s", host);
-  } else
-    memcpy((char*)&ip, (char*)&in.s_addr, 4);
+//  } else
+//{
+//    memcpy((char*)&ip, (char*)&in.s_addr, 4);
+//printf("success: %d: %d %s\n", xx, AF_INET, host);
+//}
+//
+//  printf("!!! SPECIAL DEBUG OUTPUT !!!\nPlease send the following information in if the web update fails:\n");
+//  printf("Host: %s\n", host);
+//  printf("IP (int): %d\n", ip);
+//  printf("Dump of (in):\n");
+//  amap_dump_string(stdout, (unsigned char*)&in, sizeof(in), 16);
+//  printf("\n");
+
   if ((s = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0)
     amap_error("could not get a socket");
   setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &result, sizeof(result));
@@ -172,7 +188,7 @@ int amap_webupdate_file(char *webfile, char *localfile, int checkversion, int as
   addr.sin_family = AF_INET;
   memcpy(&addr.sin_addr.s_addr, &ip, 4);
   if (connect(s, (struct sockaddr *) &addr, sizeof(addr)) < 0)
-    amap_error("could not connect to host: %s", host);
+    amap_error("could not connect to host: %s (%lu)", host, ip);
 
   if (send(s, request, strlen(request), 0) < 0)
     amap_error("web site closed connection");
@@ -683,8 +699,8 @@ amap_struct_ports *amap_add_port_string(amap_struct_ports *port_tmp, char *port,
   int pfrom, pto;
 
   if ((ptr = index(port, '-')) == NULL) {
-    if (atoi(port) < 1 || atoi(port) > 65535)
-      amap_error("ports to be scanned must be between 1 and 65535 inclusive: %s", port);
+    if (atoi(port) < 0 || atoi(port) > 65535)
+      amap_error("ports to be scanned must be between 0 and 65535 inclusive: %s", port);
     port_tmp->port = atoi(port);
     port_tmp->ip_prot = cmd_proto;
   } else {
@@ -754,13 +770,17 @@ amap_struct_targets *read_file_nmap(char *filename, amap_struct_options *opt) {
       strcpy(orig_line, line);
       ip = index(line, ' ');
       ip++;
-      ptr = amap_index(ip, '.');
-      if ((ptr = amap_index(ip, ' ')) == NULL)
-        amap_error("nmap data line fucked up: %s", orig_line);
+      if (opt->ipv6)
+        ptr = amap_index(ip, ':');
+      else
+        ptr = amap_index(ip, '.');
+      if ((ptr = amap_index(ptr, ' ')) == NULL)
+        amap_error("nmap data line fucked up (is it ipv6 but you did not use the -6 option?) : %s", orig_line);
       *ptr = 0;
       target->target = strdup(ip);
-      if (inet_addr(target->target) == -1)
-        amap_error("invalid IP address in nmap line: %s : %s", target->target, orig_line);
+      if (opt->ipv6 == 0)
+        if (inet_addr(target->target) == -1)
+          amap_error("invalid IP address in nmap line: %s : %s", target->target, orig_line);
       if (opt->verbose > 1)
         printf("DEBUG: Loading ports for %s ... ", target->target);
       while (*(portinfo - 1) != ' ')
